@@ -22,9 +22,9 @@
 #ifndef DIGITA_H
 #define DIGITA_H
 
-#include <gphoto2.h>
+#include <gphoto2/gphoto2.h>
 
-#include <gphoto2-port.h>
+#include <gphoto2/gphoto2-port.h>
 
 #define DIGITA_GET_PRODUCT_INFO         0x01
 #define DIGITA_GET_IMAGE_SPECS          0x02
