@@ -21,8 +21,8 @@
 #ifndef __FUJI_H__
 #define __FUJI_H__
 
-#include <gphoto2-context.h>
-#include <gphoto2-camera.h>
+#include <gphoto2/gphoto2-context.h>
+#include <gphoto2/gphoto2-camera.h>
 
 typedef enum _FujiCmd FujiCmd;
 enum _FujiCmd {
@@ -90,8 +90,6 @@ int fuji_upload      (Camera *, const unsigned char *data,
 int fuji_id_get      (Camera *camera, const char **id, GPContext *context);
 int fuji_id_set      (Camera *camera, const char  *id, GPContext *context);
 
-int fuji_reset       (Camera *camera, GPContext *context);
-
 typedef struct _FujiDate FujiDate;
 struct _FujiDate {
 	unsigned int year;
