@@ -26,6 +26,7 @@
  * - Coolpix P3 does not give transfer status (image 000x/000y), and reports an
  *   error when transfers finish correctly.
  */
+#define _BSD_SOURCE
 #include "config.h"
 
 #include <stdlib.h>
@@ -43,6 +44,8 @@
 #include <gphoto2/gphoto2-port-log.h>
 #include <gphoto2/gphoto2-setting.h>
 
+#define PTPIP_VERSION_MAJOR 0x0001
+#define PTPIP_VERSION_MINOR 0x0000
 
 #ifdef ENABLE_NLS
 #  include <libintl.h>
@@ -110,6 +113,7 @@ ptp_ptpip_sendreq (PTPParams* params, PTPContainer* req)
 	}
 	gp_log_data ( "ptpip/oprequest", (char*)request, len);
 	ret = write (params->cmdfd, request, len);
+	free (request);
 	if (ret == -1)
 		perror ("sendreq/write to cmdfd");
 	if (ret != len) {
@@ -210,17 +214,12 @@ ptp_ptpip_check_event (PTPParams* params) {
 #define WRITE_BLOCKSIZE 65536
 uint16_t
 ptp_ptpip_senddata (PTPParams* params, PTPContainer* ptp,
-			unsigned char *data, unsigned int size,
-			int to_fd)
-{
+		unsigned long size, PTPDataHandler *handler
+) {
 	unsigned char	request[16];
 	int		ret, curwrite, towrite;
 	unsigned char*	xdata;
 
-	if (to_fd != -1) {
-		gp_log (GP_LOG_ERROR, "ptpip/senddata", "fd transfers not supported.");
-		return PTP_RC_GeneralError;
-	}
 	htod32a(&request[ptpip_type],PTPIP_START_DATA_PACKET);
 	htod32a(&request[ptpip_len],sizeof(request));
 	htod32a(&request[ptpip_startdata_transid  + 8],ptp->Transaction_ID);
@@ -237,7 +236,7 @@ ptp_ptpip_senddata (PTPParams* params, PTPContainer* ptp,
 	if (!xdata) return PTP_RC_GeneralError;
 	curwrite = 0;
 	while (curwrite < size) {
-		int type, written, towrite2;
+		unsigned long type, written, towrite2, xtowrite;
 
 		ptp_ptpip_check_event (params);
 
@@ -248,39 +247,40 @@ ptp_ptpip_senddata (PTPParams* params, PTPContainer* ptp,
 		} else {
 			type	= PTPIP_END_DATA_PACKET;
 		}
-		towrite2 = towrite+12;
+		ret = handler->getfunc (params, handler->private, towrite, &xdata[ptpip_data_payload+8], &xtowrite);
+		if (ret == -1) {
+			perror ("getfunc in senddata failed");
+			free (xdata);
+			return PTP_RC_GeneralError;
+		}
+		towrite2 = xtowrite + 12;
 		htod32a(&xdata[ptpip_type], type);
 		htod32a(&xdata[ptpip_len], towrite2);
 		htod32a(&xdata[ptpip_data_transid+8], ptp->Transaction_ID);
-		memcpy (&xdata[ptpip_data_payload+8], data+curwrite, towrite);
 		gp_log_data("ptpip/senddata", (char*)xdata, towrite2);
 		written = 0;
-		while (written > towrite2) {
+		while (written < towrite2) {
 			ret = write (params->cmdfd, xdata+written, towrite2-written);
 			if (ret == -1) {
 				perror ("write in senddata failed");
+				free (xdata);
 				return PTP_RC_GeneralError;
 			}
 			written += ret;
 		}
 		curwrite += towrite;
 	}
+	free (xdata);
 	return PTP_RC_OK;
 }
 
 uint16_t
-ptp_ptpip_getdata (PTPParams* params, PTPContainer* ptp,
-		unsigned char **data, unsigned int *readlen, int to_fd)
-{
+ptp_ptpip_getdata (PTPParams* params, PTPContainer* ptp, PTPDataHandler *handler) {
 	PTPIPHeader		hdr;
 	unsigned char		*xdata = NULL;
 	uint16_t 		ret;
-	int			toread, curread;
-
-	if (to_fd != -1) {
-		gp_log (GP_LOG_ERROR, "ptpip/getdata", "fd transfers not handled yet");
-		return PTP_RC_GeneralError;
-	}
+	unsigned long		toread, curread;
+	int			xret;
 
 	ret = ptp_ptpip_cmd_read (params, &hdr, &xdata);
 	if (ret != PTP_RC_OK)
@@ -292,44 +292,56 @@ ptp_ptpip_getdata (PTPParams* params, PTPContainer* ptp,
 	}
 	if (dtoh32(hdr.type) != PTPIP_START_DATA_PACKET) {
 		gp_log (GP_LOG_ERROR, "ptpip/getdata", "got reply type %d\n", dtoh32(hdr.type));
-		free (data);
 		return PTP_RC_GeneralError;
 	}
 	toread = dtoh32a(&xdata[ptpip_data_payload]);
 	free (xdata); xdata = NULL;
-
-	*readlen = toread;
-	*data = malloc(toread);
 	curread = 0;
 	while (curread < toread) {
 		ret = ptp_ptpip_cmd_read (params, &hdr, &xdata);
 		if (ret != PTP_RC_OK)
 			return ret;
 		if (dtoh32(hdr.type) == PTPIP_END_DATA_PACKET) {
-			int datalen = dtoh32(hdr.length)-8-ptpip_data_payload;
+			unsigned long written;
+			unsigned long datalen = dtoh32(hdr.length)-8-ptpip_data_payload;
 			if (datalen > (toread-curread)) {
 				gp_log (GP_LOG_ERROR, "ptpip/getdata",
-					"returned data is too much, expected %d, got %d",
+					"returned data is too much, expected %ld, got %ld",
 					(toread-curread),datalen
 				);
 				break;
 			}
-			memcpy ((*data)+curread, xdata+ptpip_data_payload, datalen);
-			curread += datalen;
+			xret = handler->putfunc (params, handler->private,
+				datalen, xdata+ptpip_data_payload, &written
+			);
+			if (xret == -1) {
+				gp_log (GP_LOG_ERROR, "ptpip/getdata",
+					"failed to putfunc of returned data");
+				break;
+			}
+			curread += written;
 			free (xdata); xdata = NULL;
 			continue;
 		}
 		if (dtoh32(hdr.type) == PTPIP_DATA_PACKET) {
-			int datalen = dtoh32(hdr.length)-8-ptpip_data_payload;
+			unsigned long written;
+			unsigned long datalen = dtoh32(hdr.length)-8-ptpip_data_payload;
 			if (datalen > (toread-curread)) {
 				gp_log (GP_LOG_ERROR, "ptpip/getdata",
-					"returned data is too much, expected %d, got %d",
+					"returned data is too much, expected %ld, got %ld",
 					(toread-curread),datalen
 				);
 				break;
 			}
-			memcpy ((*data)+curread, xdata+ptpip_data_payload, datalen);
-			curread += datalen;
+			xret = handler->putfunc (params, handler->private,
+				datalen, xdata+ptpip_data_payload, &written
+			);
+			if (xret == -1) {
+				gp_log (GP_LOG_ERROR, "ptpip/getdata",
+					"failed to putfunc of returned data");
+				break;
+			}
+			curread += written;
 			free (xdata); xdata = NULL;
 			continue;
 		}
@@ -390,7 +402,6 @@ ptp_ptpip_init_command_request (PTPParams* params)
 	unsigned char	guid[16];
 	
 	ptp_nikon_getptpipguid(guid);
-	
 	if (gethostname (hostname, sizeof(hostname)))
 		return PTP_RC_GeneralError;
 	len = ptpip_initcmd_name + (strlen(hostname)+1)*2 + 4;
@@ -405,9 +416,12 @@ ptp_ptpip_init_command_request (PTPParams* params)
 		cmdrequest[ptpip_initcmd_name+i*2] = hostname[i];
 		cmdrequest[ptpip_initcmd_name+i*2+1] = 0;
 	}
+	htod16a(&cmdrequest[ptpip_initcmd_name+(strlen(hostname)+1)*2],PTPIP_VERSION_MAJOR);
+	htod16a(&cmdrequest[ptpip_initcmd_name+(strlen(hostname)+1)*2+2],PTPIP_VERSION_MINOR);
 
 	gp_log_data ( "ptpip/init_cmd", (char*)cmdrequest, len);
 	ret = write (params->cmdfd, cmdrequest, len);
+	free (cmdrequest);
 	if (ret == -1) {
 		perror("write init cmd request");
 		return PTP_RC_GeneralError;
@@ -433,10 +447,9 @@ ptp_ptpip_init_command_ack (PTPParams* params)
 	int		i;
 	unsigned short	*name;
 
-	ret = ptp_ptpip_cmd_read (params, &hdr, &data);
-	if (ret != PTP_RC_OK) {
+	ret = ptp_ptpip_generic_read (params, params->cmdfd, &hdr, &data);
+	if (ret != PTP_RC_OK)
 		return ret;
-	}
 	if (hdr.type != dtoh32(PTPIP_INIT_COMMAND_ACK)) {
 		gp_log (GP_LOG_ERROR, "ptpip/init_cmd_ack", "bad type returned %d", htod32(hdr.type));
 		return PTP_RC_GeneralError;
@@ -591,7 +604,14 @@ ptp_ptpip_connect (PTPParams* params, const char *address) {
 	if (NULL == strchr (address,':'))
 		return GP_ERROR_BAD_PARAMETERS;
 	addr = strdup (address);
-	s = strchr (addr,':'); *s = '\0';
+	if (!addr)
+		return GP_ERROR_NO_MEMORY;
+	s = strchr (addr,':');
+	if (!s) {
+		gp_log (GP_LOG_ERROR,"ptpip/connect", "addr %s should contain a :", address);
+		return GP_ERROR_BAD_PARAMETERS;
+	}
+	*s = '\0';
 	p = strchr (s+1,':');
 	port = 15740;
 	if (p) {
