@@ -306,6 +306,11 @@ camera_abilities (CameraAbilitiesList *list)
 	a.usb_product	= 0x2217;
 	gp_abilities_list_append(list, a);
 
+	strcpy(a.model, "Ricoh:Caplio R5");
+	a.usb_vendor	= 0x5ca;
+	a.usb_product	= 0x221a;
+	gp_abilities_list_append(list, a);
+
 	return (GP_OK);
 }
 
@@ -467,6 +472,7 @@ delete_file_func (CameraFilesystem *fs, const char *folder,
 		return ret;
 
 	cmd = malloc(strlen("DELE ")+strlen(filename)+1);
+	if (!cmd) return GP_ERROR_NO_MEMORY;
 	sprintf(cmd,"DELE %s",filename);
 	ret = g3_ftp_command_and_reply(camera->port, cmd, &reply);
 	if (ret < GP_OK)
@@ -494,6 +500,7 @@ rmdir_func (CameraFilesystem *fs, const char *folder,
 		return ret;
 
 	cmd = realloc(cmd,strlen("RMD ")+strlen(name)+1);
+	if (!cmd) return GP_ERROR_NO_MEMORY;
 	sprintf(cmd,"RMD %s",name);
 	ret = g3_ftp_command_and_reply(camera->port, cmd, &reply);
 	if (ret < GP_OK)
@@ -521,6 +528,7 @@ mkdir_func (CameraFilesystem *fs, const char *folder,
 		return ret;
 
 	cmd = realloc(cmd,strlen("MKD ")+strlen(name)+1);
+	if (!cmd) return GP_ERROR_NO_MEMORY;
 	sprintf(cmd,"MKD %s",name);
 	ret = g3_ftp_command_and_reply(camera->port, cmd, &reply);
 	if (ret < GP_OK)
@@ -660,7 +668,7 @@ get_info_func (CameraFilesystem *fs, const char *folder, const char *filename,
 		!strcmp(info->file.type,GP_MIME_AVI)
 	) {
 		sprintf(cmd, "-INFO %s/%s", folder,filename);
-		g3_ftp_command_and_reply(camera->port, cmd, &reply);
+		ret = g3_ftp_command_and_reply(camera->port, cmd, &reply);
 		if (ret < GP_OK) goto out;
 
 		/* 200 1330313 byte W=2048 H=1536 K=0 for -INFO */
@@ -712,7 +720,7 @@ folder_list_func (CameraFilesystem *fs, const char *folder, CameraList *list,
 		}
 		ret = g3_channel_read(camera->port, &channel, &buf, &len); /* data. */
 		if (ret < GP_OK) goto out;
-		g3_channel_read(camera->port, &channel, &reply, &rlen); /* next reply  */
+		ret = g3_channel_read(camera->port, &channel, &reply, &rlen); /* next reply  */
 		if (ret < GP_OK) goto out;
 		gp_log(GP_LOG_DEBUG, "g3" , "reply %s", reply);
 
@@ -857,7 +865,6 @@ file_list_func (CameraFilesystem *fs, const char *folder, CameraList *list,
 out:
 	if (buf) free(buf);
 	if (reply) free(reply);
-	if (cmd) free(cmd);
 	return (GP_OK);
 }
 
