@@ -27,9 +27,9 @@
 # include <jpeglib.h>
 #endif
 
-#include <gphoto2-library.h>
-#include <gphoto2-port-log.h>
-#include <gphoto2-result.h>
+#include <gphoto2/gphoto2-library.h>
+#include <gphoto2/gphoto2-port-log.h>
+#include <gphoto2/gphoto2-result.h>
 
 #ifdef ENABLE_NLS
 #  include <libintl.h>
@@ -216,8 +216,10 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 		buf[6] = (len >>  8) & 0xff;
 		buf[7] =  len        & 0xff;
 		result = gp_port_usb_msg_write (camera->port,BLINK2_GET_MEMORY,0x03,0,buf,8);
-		if (result < GP_OK)
+		if (result < GP_OK) {
+			free (jpegdata);
 			break;
+		}
 		len	*= 8;
 		curread  = 0;
 		do {
@@ -242,8 +244,11 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 		jpeg_create_decompress(&dinfo);
 		dinfo.src		= &xjsm;
 		ret = jpeg_read_header(&dinfo,TRUE);
-		if (ret != JPEG_HEADER_OK)
+		if (ret != JPEG_HEADER_OK) {
+			jpeg_destroy_decompress(&dinfo);
+			free (jpegdata);
 			break;
+		}
 		dinfo.out_color_space = JCS_RGB;
 		jpeg_start_decompress(&dinfo);
 
@@ -375,7 +380,7 @@ camera_capture (Camera *camera, CameraCaptureType type, CameraFilePath *path,
 		if (ret < GP_OK)
 			return ret;
 		sleep(1);
-	} while (buf[1] == 0x00);
+	} while (buf[0] == 0x00);
 
 	ret = blink2_getnumpics (camera->port, context, &numpics);
 	if (ret < GP_OK)
@@ -440,6 +445,7 @@ camera_init (Camera *camera, GPContext *context)
 
 	gp_filesystem_set_funcs (camera->fs, &fsfuncs, camera);
 	gp_port_get_settings( camera->port, &settings);
+	settings.usb.config = 1;
 	settings.usb.interface = 0;
 	settings.usb.altsetting = 0;
 	ret = gp_port_set_settings (camera->port, settings);
