@@ -27,7 +27,7 @@
 #ifndef __SPCA50X_H__
 #define __SPCA50X_H__
 #include <_stdint.h>
-#include <gphoto2-camera.h>
+#include <gphoto2/gphoto2-camera.h>
 
 #define SPCA50X_FAT_PAGE_SIZE 0x100
 #define SPCA50X_FILE_TYPE_IMAGE 0x00
